@@ -20,8 +20,9 @@
 
 package Lintian::usr::lib;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Moo;
@@ -32,6 +33,10 @@ with 'Lintian::Check';
 sub files {
     my ($self, $file) = @_;
 
+    # see Bug#959037 for details
+    return
+      if $self->type eq 'udeb';
+
     return
       unless $file->name =~ m{^usr/lib/};
 
