@@ -20,10 +20,9 @@
 
 package Lintian::Processable::Fields::Files;
 
-use strict;
+use v5.20;
 use warnings;
-
-use Lintian::Util qw(strip);
+use utf8;
 
 use Moo::Role;
 use namespace::clean;
@@ -110,10 +109,13 @@ sub files {
     local $_;
 
     for (split /\n/, $file_list) {
-        strip;
+
+        # trim both ends
+        s/^\s+|\s+$//g;
+
         next if $_ eq '';
 
-        my @fields = split(/\s+/o, $_);
+        my @fields = split(/\s+/, $_);
         my $file = $fields[-1];
 
         next
@@ -141,10 +143,13 @@ sub files {
         my $list = $self->field("checksums-$alg") || '';
 
         for (split /\n/, $list) {
-            strip;
+
+            # trim both ends
+            s/^\s+|\s+$//g;
+
             next if $_ eq '';
 
-            my ($checksum, $size, $file) = split(/\s+/o, $_);
+            my ($checksum, $size, $file) = split(/\s+/, $_);
             next if $file =~ m,/,;
 
             $files{$file}{checksums}{$alg} = {
